%define major		3
%define libname		%mklibname opensubdiv %{major}
%define develname	%mklibname -d opensubdiv
%define staticname	%mklibname -s -d opensubdiv

%define fver   3_6_0

%define use_cuda 0
%{?_with_use_cuda: %global use_cuda 1}
%{?_without_use_cuda: %global use_cuda 0}

Name:		opensubdiv
Version:	3.6.0
Release:	%mkrel 2
Summary:	High performance subdivision surface libraries
Group:		Graphics/3D
License:	Apache License
#Url:		http://graphics.pixar.com/opensubdiv/
Url:		https://github.com/PixarAnimationStudios/OpenSubdiv
Source0:	https://github.com/PixarAnimationStudios/OpenSubdiv/archive/v%{fver}/%{name}-%{version}.tar.gz
Patch0:		opensubdiv-3.3.3-fix-major-soname.patch
# fix linking against libdl (see https://github.com/PixarAnimationStudios/OpenSubdiv/issues/1196)
Patch2:		opensubdiv-rpath.patch
Patch3:		opensubdiv-3.5.1-fix-dlopen-linking.patch
# From openmandriva
Patch4:		OpenSubdiv-3.6.0-find-OpenCL.patch
# Upstream patches
#
BuildRequires:	cmake
BuildRequires:	libgomp-devel
%if %{use_cuda}
BuildRequires:	nvidia-cuda-toolkit >= 4.0
BuildRequires:	nvidia-cuda-toolkit-devel >= 4.0
%endif
BuildRequires:	pkgconfig(OpenCL) >= 1.1
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(glfw3) >= 3.0.0
BuildRequires:	pkgconfig(ice)
BuildRequires:	pkgconfig(ptex)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(tbb)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xcursor)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(xi)
BuildRequires:	pkgconfig(xinerama)
BuildRequires:	pkgconfig(xrandr)
# for doc building
BuildRequires:	doxygen >= 1.8.4
BuildRequires:	rst2html >= 0.9

%description
OpenSubdiv is a set of open source libraries that implement high
performance subdivision surface (subdiv) evaluation on massively
parallel CPU and GPU architectures. This code path is optimized for
drawing deforming surfaces with static topology at interactive
frame rates.

OpenSubdiv is an API ready to be integrated into 3rd party digital
content creation tools. It is not an application, nor a tool that can
be used directly to create digital assets.

%package doc
Summary:	High performance subdivision surface libraries
Group:		Documentation
BuildArch:	noarch

%description doc
OpenSubdiv is a set of open source libraries that implement high
performance subdivision surface (subdiv) evaluation on massively
parallel CPU and GPU architectures. This code path is optimized for
drawing deforming surfaces with static topology at interactive
frame rates.

This package includes the documentation of OpenSubdiv.

%package -n %{libname}
Summary:	High performance subdivision surface libraries
Group:		System/Libraries
Requires:	%{_lib}glfw3 >= 3.0

%description -n %{libname}
OpenSubdiv is a set of open source libraries that implement high
performance subdivision surface (subdiv) evaluation on massively
parallel CPU and GPU architectures. This code path is optimized for
drawing deforming surfaces with static topology at interactive
frame rates.

OpenSubdiv is an API ready to be integrated into 3rd party digital
content creation tools. It is not an application, nor a tool that can
be used directly to create digital assets.

This package contains the shared library of OpenSubdiv.

%package -n %{develname}
Summary:	Development files for the OpenSubdiv library
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	opensubdiv-devel = %{version}-%{release}

%description -n %{develname}
Development files for the OpenSubdiv library. Install this package if you
want to compile applications using the OpenSubDiv library.

%package -n %{staticname}
Summary:	Static libraries for linking to OpenSubdiv
Group:		Development/C
Requires:	%{develname} = %{version}-%{release}
Provides:	%{name}-static = %{version}-%{release}
Provides:	opensubdiv-static-devel = %{version}-%{release}

%description -n %{staticname}
Static libraries for OpenSubdiv.


%prep
%autosetup -n OpenSubdiv-%{fver} -p1

%build

%cmake	\
	-DBUILD_STATIC_LIBS:BOOL=ON \
	-DCMAKE_LIBDIR_BASE:PATH=%{_libdir} \
	-DGLEW_LOCATION:PATH=%{_prefix} \
	-DGLFW_LOCATION:PATH=%{_prefix} \
	-DNO_CLEW:BOOL=ON \
%if %{use_cuda}
	-DNO_CUDA:BOOL=OFF \
	-DOSD_CUDA_NVCC_FLAGS:STRING="--gpu-architecture=compute_35" \
%else
	-DNO_CUDA:BOOL=ON \
%endif
	-DNO_GLFW:BOOL=OFF \
	-DNO_EXAMPLES:BOOL=ON \
	-DNO_METAL:BOOL=ON \
	-DNO_OMP:BOOL=OFF \
	-DNO_OPENCL:BOOL=OFF \
	-DNO_PTEX:BOOL=ON \
	-DNO_REGRESSION:BOOL=ON \
	-DNO_TUTORIALS:BOOL:=ON \
	-DNO_DOC:BOOL:=OFF

%cmake_build

%install
%cmake_install
rm -f %{buildroot}%{_bindir}/stringify

%files doc
%{_datadir}/doc/%{name}

%files -n %{libname}
%doc LICENSE.txt NOTICE.txt README.md
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%dir %{_libdir}/cmake/OpenSubdiv
%{_libdir}/lib*.so
%{_includedir}/*
%{_libdir}/cmake/OpenSubdiv/*.cmake

%files -n %{staticname}
%{_libdir}/*.a


%changelog
* Mon Jun 30 2025 umeabot <umeabot> 3.6.0-2.mga10
+ Revision: 2230502
- Mageia 10 Mass Rebuild

* Fri Nov 29 2024 daviddavid <daviddavid> 3.6.0-1.mga10
+ Revision: 2119995
- new version: 3.6.0

* Sun Jan 28 2024 daviddavid <daviddavid> 3.5.1-2.mga10
+ Revision: 2035700
- backport upstream patch to add oneTBB 2021 support
- rebuild for tbb 2021.11.0

* Tue Jan 16 2024 ghibo <ghibo> 3.5.1-1.mga10
+ Revision: 2031438
- Update to release 3.5.1.
- Drop patch merged upstream.
- Rework -dlopen and -soname patches.

* Wed Feb 01 2023 ghibo <ghibo> 3.4.4-4.mga9
+ Revision: 1937506
- Merge patch from OpenMandriva to fix building against latest OpenCL
- Rebuild for aging

* Mon Apr 04 2022 umeabot <umeabot> 3.4.4-2.mga9
+ Revision: 1844025
- Mageia 9 Mass Rebuild

* Tue Dec 28 2021 ghibo <ghibo> 3.4.4-1.mga9
+ Revision: 1765097
- Update to release 3.4.4.
- Rediff patch1.
- Raise cuda compute capability to 3.5.

* Wed Dec 02 2020 luigiwalser <luigiwalser> 3.4.3-2.mga8
+ Revision: 1651366
- rebuild for glew

* Sun Sep 13 2020 ghibo <ghibo> 3.4.3-1.mga8
+ Revision: 1625526
- Add 2nd patch for dlopen linking issues
- Fix linking bug against libdl
- Update to release 3.4.3

* Wed Feb 19 2020 umeabot <umeabot> 3.4.0-3.mga8
+ Revision: 1544556
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 daviddavid <daviddavid> 3.4.0-2.mga8
+ Revision: 1483295
- add patch to port build of documentation to python3
- disable doc for now once it will be ported to python3
- new version: 3.4.0
+ wally <wally>
- build with new cmake macros

* Fri Apr 26 2019 ghibo <ghibo> 3.3.3-6.mga7
+ Revision: 1395556
- Add flags for building with cuda

* Fri Apr 26 2019 ghibo <ghibo> 3.3.3-5.mga7
+ Revision: 1395451
- Add xinerama to BR
- Add xcursor to BR
- Add xrandr to BR
- Rebuild against GLFW 3.3.

* Wed Apr 24 2019 ghibo <ghibo> 3.3.3-4.mga7
+ Revision: 1395119
- Split doc package

* Wed Apr 24 2019 ghibo <ghibo> 3.3.3-3.mga7
+ Revision: 1395108
- Add ICE to BR.
- Add rst2html to BR for docs.

* Tue Apr 23 2019 ghibo <ghibo> 3.3.3-2.mga7
+ Revision: 1395047
- Add missed libgomp-devel in BuildRequires
- Fix typo in description.
- Use PATH type for cmake arguments.

* Tue Apr 23 2019 ghibo <ghibo> 3.3.3-1.mga7
+ Revision: 1395008
- fix soname adding Patch1 (credits to David Geiger)
- fix libpath for 64bit (David Geiger)
- removed CMAKE_BUILD_TYPE=Release (David Geiger)
- removed %%clean section (David Geiger)
- remove trailing dot in Summary (kekePower)
- add docs
- Added a fix for aarch64
- Add xi to BuildRequires
- imported package opensubdiv


* Tue Apr 23 2019 ghibo <ghibo> 3.3.3-1.mga7
- Initial release.
